# plot-data

[![npm (scoped)](https://img.shields.io/npm/v/plot-data.svg)](https://www.npmjs.com/package/plot-data)
[![npm bundle size (minified)](https://img.shields.io/bundlephobia/min/plot-data.svg)](https://www.npmjs.com/package/plot-data)
![npm](https://img.shields.io/npm/dt/plot-data)
![GitHub last commit](https://img.shields.io/github/last-commit/Dessia-tech/plot_data)

## Install

```
npm i plot-data
```

## Usage

```
import * as plotdata from 'plot-data';
```

## Develop

```
npm i
npm run-script build
```

## Documentation

Python: https://documentation.dessia.tech/plot_data/python/ <br>
Typescript: https://documentation.dessia.tech/plot_data/typescript/

## Changelog

Check the changelog [here](CHANGELOG.md)